@@ -629,38 +629,12 @@ __imlib_ProduceLoader(char *file)
 char **
 __imlib_ListLoaders(int *num_ret)
 {
-   char **list = NULL, **l, *s, *home;
+   char **list = NULL, **l, *s;
    int num, i, pi = 0;
 
    *num_ret = 0;
-   /* get the user's home dir */
-   home = __imlib_FileHomeDir(getuid());
-   s = (char *) malloc(strlen(home) + 1 + sizeof(USER_LOADERS_PATH) + 6 + 1);
-   sprintf(s, "%s/" USER_LOADERS_PATH "/image", home);
-   /* list the dir contents of their loader dir */
-   l = __imlib_FileDir(s, &num);
-   /* if theres files */
-   if (num > 0)
-   {
-      /* make a list of them */
-      *num_ret += num;
-      list = malloc(sizeof(char *) * *num_ret);
-
-      for (i = 0; i < num; i++)
-      {
-         s = (char *) realloc(s, strlen(home) + 1 + sizeof(USER_LOADERS_PATH) + 7 + strlen(l[i]) + 1);
-	 sprintf(s, "%s/" USER_LOADERS_PATH "/image/%s", home, l[i]);
-#ifndef __EMX__
-	 list[pi + i] = strdup(s);
-#else
-	 list[pi + i] = strdup(__XOS2RedirRoot(s));
-#endif
-      }
-      pi = i;
-      __imlib_FileFreeDirList(l, num);
-   }
    /* same for system loader path */
-   s = (char *) realloc(s, sizeof(SYS_LOADERS_PATH) + 6 + 1);
+   s = (char *) malloc(sizeof(SYS_LOADERS_PATH) + 6 + 1);
    sprintf(s, SYS_LOADERS_PATH "/image");
 #ifndef __EMX__   
    l = __imlib_FileDir(s, &num);
@@ -684,7 +658,6 @@ __imlib_ListLoaders(int *num_ret)
       }
       __imlib_FileFreeDirList(l, num);
    }
-   free(home);
    free(s);
 
    /* List currently contains *everything in there* we need to weed out
@@ -811,22 +784,6 @@ __imlib_RescanLoaders(void)
          last_modified_system_time = current_time;
       }
    }
-   /* ok - was the users own loaders dir contents modified ? */
-   home = __imlib_FileHomeDir(getuid());
-   s = (char *) malloc(strlen(home) + 1 + sizeof(USER_LOADERS_PATH) + 7 + 1);
-   sprintf(s, "%s/" USER_LOADERS_PATH "/image/", home);
-   free(home);
-   if (__imlib_FileIsDir(s))
-   {
-      current_time = __imlib_FileModDate(s);
-      if (current_time > last_modified_home_time)
-      {
-         /* yup - set the "do_reload" flag */
-         do_reload = 1;
-         last_modified_home_time = current_time;
-      }
-   }
-   free(s);
    /* if we dont ned to reload the loaders - get out now */
    if (!do_reload)
       return;
